import { ConversationType, getCurrentUserId, MessageType } from "@rongcloud/imlib-next";
import { h } from "@stencil/core";
import { core } from "../../../core";
import { addBase64head, formatTextMessage } from "../../../utils/utils";
import { ACreateMessage } from "./base";
import language from "../../../../src/language/index";
export default class ReferenceMessage extends ACreateMessage {
  constructor(message, callback) {
    super(message, callback);
    this.getName(message);
  }
  getName(message) {
    this.name = this.content.referMsgUserId;
    const conversationOption = {
      conversationType: message.conversationType,
      targetId: message.targetId,
      channelId: message.channelId
    };
    if (message.conversationType === ConversationType.GROUP) {
      core.getGroupMemberProfile(conversationOption, this.name).then(res => {
        if (!res) {
          return;
        }
        this.name = res.groupNickname || res.name;
        if (this.nameRef) {
          this.nameRef.innerText = this.name;
        }
      });
    }
    else if (message.conversationType === ConversationType.PRIVATE) {
      let promise;
      if (message.content.referMsgUserId === getCurrentUserId()) {
        promise = core.getMyProfile();
      }
      else {
        promise = core.getConversationProfile(conversationOption);
      }
      promise.then(res => {
        if (!res) {
          return;
        }
        this.name = res.displayName || res.name;
        if (this.nameRef) {
          this.nameRef.innerText = this.name;
        }
      });
    }
  }
  getRererenceContent(type, referMsg) {
    let content = "";
    let handledContent = "";
    let lang = core.lang ? core.lang : language.zh_CN;
    let locale = language[lang];
    switch (type) {
      case MessageType.TEXT:
        content = referMsg.content.content;
        handledContent = formatTextMessage(content);
        content = (h("div", { innerHTML: handledContent, class: "referenced-message-text" },
          h("div", { class: "quote quoteContent", innerHTML: handledContent })));
        break;
      case MessageType.IMAGE:
        content = h("img", { src: addBase64head(referMsg.content.content) });
        break;
      case MessageType.GIF:
        content = h("img", { src: referMsg.content.remoteUrl });
        break;
      case MessageType.FILE:
        // content = `[文件] ${referMsg.content.name}`;
        content = '[' + locale.conversation.file + ']' + ` ${referMsg.content.name}`;
        break;
      case MessageType.RICH_CONTENT:
        // content = `[图文] ${referMsg.content.title}`;
        content = '[' + locale.conversation.img + ']' + ` ${referMsg.content.title}`;
        break;
      case MessageType.REFERENCE:
        // content = "[引用消息]" + (referMsg.content as any).content;
        content = referMsg.content.content;
        break;
    }
    return content;
  }
  create() {
    const content = this.content;
    return this.wrap(h("div", { class: "reference-message-body" },
      h("div", { class: "reference-message-content" },
        h("div", { class: "user", ref: el => (this.nameRef = el) }, this.name),
        h("div", { class: "content" }, this.getRererenceContent(content.objName, content.referMsg))),
      h("div", { class: "message-content", innerHTML: formatTextMessage(content.content) })));
  }
}
