import Vue from "vue";
import Router from "vue-router";

Vue.use(Router);

/* Layout */
import Layout from "@/layout";

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  // {
  //   path: '/main',
  //   name: '首页',
  //   component: Layout,
  //   hidden: true,
  //   meta: {
  //     noCache: '1',
  //     title: '首页'
  //   },
  //   children:
  // },
  {
    path: "/instructions", // 侧边栏
    component: Layout,
    hidden: true,
    children: [
      {
        name: "说明文档",
        path: "instructions",
        component: () => import("@/layout/components/fullPageIns"),
        hidden: true,
        meta: {
          noCache: "1",
          title: "说明文档"
        }
      }
    ]
  },
  // {
  //   path: '/photo-detail', // 相册详情
  //   component: Layout,
  //   hidden: true,
  //   children: [
  //   {
  //     name: '相册详情',
  //     path: ':id',
  //     component: () => import('@/views/photo-detail'),
  //     hidden: true,
  //     meta: {
  //       noCache: '1',
  //       title: '相册详情'
  //     }
  //   }]
  // },
  {
    path: "/setSilder", // 侧边栏
    component: Layout,
    hidden: true,
    children: [
      {
        name: "提交表单",
        path: "save-form",
        component: () => import("@/views/save-form-test"),
        hidden: true,
        meta: {
          noCache: "1",
          title: "提交表单"
        }
      }
    ]
  },
  {
    path: "/login",
    name: "登录",
    component: () => import("@/views/login/index"),
    hidden: true
  },

  {
    path: "/",
    redirect: "/main",
    hidden: true
  },
  {
    path: "/redirect",
    component: () => import("@/views/Layout/centerpage"),
    hidden: true
  },
  {
    path: "/404",
    component: () => import("@/views/404"),
    hidden: true
  },
  {
    path: "/403",
    component: () => import("@/views/403"),
    hidden: true
  },
  {
    path: "/noPermission",
    component: () => import("@/views/noPermission"),
    hidden: true
  },
  {
    path: "/systemMaintain",
    component: () => import("@/views/systemMaintain"),
    hidden: true
  }
  // { path: '*', redirect: '/404', hidden: true }
];
// export const constantRoutes = [{
//   path: '/',
//   redirect: '/upms',
// }]
const createRouter = () =>
  new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({
      y: 0
    }),
    routes: constantRoutes
  });

const router = createRouter();

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter();
  router.matcher = newRouter.matcher; // reset router
}
export const asyncRoutes = {
  Layout: Layout,
  // 首页
  main: () => import("@/views/main/index"),
  // 内容管理
  contentManager: () => import("@/views/contentManager/index"),
  platformIndex: () => import("@/views/contentManager/platformIndex"),
  accompaniment: () => import("@/views/accompaniment"),
  contentOperation: () => import("@/views/contentManager/contentOperation"),
  // 系统日志
  journal: () => import("@/views/workBenchManager/journal/index"),
  // 课酬确认
  classFeesIsOk: () => import("@/views/workBenchManager/classFeesIsOk"),
  // 课酬申诉
  requestProcessing: () => import("@/views/workBenchManager/requestProcessing"),
  // 考勤申诉
  payAppeal: () => import("@/views/workBenchManager/payAppeal"),
  // 乐团管理
  teamDetail: () => import("@/views/teamDetail/teamList"),
  teamBuild: () => import("@/views/teamBuild/index"), // 新建
  teamDraft: () => import("@/views/teamBuild/teamDraft"), // 编辑
  teamAudit: () => import("@/views/teamBuild/teamDraft"), // 审核
  feeAudit: () => import("@/views/teamBuild/teamDraft"), // 费用审核
  auditFailed: () => import("@/views/teamBuild/teamDraft"), // 审核失败
  forecastName: () => import("@/views/teamBuild/forecastNameList"), // 预报名页面forecastName
  createPayment: () => import("@/views/teamBuild/createPayment"), // 创建缴费页面
  // VIP管理
  vipList: () => import("@/views/vipClass/vipList"),
  // vip修改
  vipReset: () => import("@/views/vipClass/vipReset"),
  // vip详情
  // @/views/buildVip/index   @/views/vipClass/vipDetail
  vipDetail: () => import("@/views/vipClass/vipDetail"),
  buildVip: () => import("@/views/buildVip/index"),
  // 教师管理
  teacherList: () => import("@/views/teacherManager/teacherList"),
  // 新增&修改教师
  teacherOperation: () =>
    import("@/views/teacherManager/teacherOperation/index"),
  teacherOperationUpdate: () =>
    import("@/views/teacherManager/teacherOperation/index"),
  // 老师详情
  teacherDetail: () => import("@/views/teacherManager/teacherDetail/index"),
  // 学员管理
  studentList: () => import("@/views/studentManager/studentList"),
  // 学员详情
  studentDetail: () => import("@/views/studentManager/index"),
  // 订单管理
  orderList: () => import("@/views/businessManager/orderManager/index"),
  // 订单列表
  income: () => import("@/views/businessManager/orderManager/income"),
  incomeOne: () => import("@/views/businessManager/orderManager/incomeOne"),
  incomeTwo: () => import("@/views/businessManager/orderManager/incomeTwo"),
  // 财务管理（含陶气）
  "financeManager-taoqi": () =>
    import("@/views/businessManager/orderManager/financeManager-taoqi"),
  // 财务管理
  financeManager: () =>
    import("@/views/businessManager/orderManager/financeManager"),
  // 充值列表
  incomebuy: () => import("@/views/businessManager/orderManager/incomebuy"),
  // 退费订单
  backOrder: () => import("@/views/businessManager/orderManager/backMoney"),
  // 支出
  expend: () => import("@/views/businessManager/orderManager/expend"),
  // 商品管理
  shopManager: () => import("@/views/businessManager/shopManager/shopList"),
  // 商品修改（添加）
  shopOperation: () =>
    import("@/views/businessManager/shopManager/shopOperation"),
  // 商品类型管理
  shopCategory: () =>
    import("@/views/businessManager/shopManager/shopCategory"),
  // 报表中心
  reportForm: () => import("@/views/reportForm/index"),
  // musicalManager: () => import('@/views/categroyManager/specialSetup/musicalManager'),
  // 系统管理
  specialSetup: () => import("@/views/categroyManager/specialSetup/index"),
  // 类型管理
  typesManager: () =>
    import("@/views/categroyManager/specialSetup/typesManager"),
  tryClass: () => import("@/views/categroyManager/specialSetup/tryClass"),
  activityManager: () =>
    import("@/views/categroyManager/specialSetup/activityManager"),
  tempalteManager: () =>
    import("@/views/categroyManager/specialSetup/tempalteManager"),
  bannerManager: () =>
    import("@/views/categroyManager/specialSetup/bannerManager"),
  holidayManager: () =>
    import("@/views/categroyManager/specialSetup/holidayManager"),
  branchSetting: () =>
    import("@/views/categroyManager/specialSetup/branchSetting"),
  jobTemplateSetting: () =>
    import("@/views/categroyManager/specialSetup/jobTemplateSetting"),
  generalSettings: () =>
    import("@/views/categroyManager/generalSettings/index"),
  siginManager: () =>
    import("@/views/categroyManager/generalSettings/siginManager"),
  leaveManager: () =>
    import("@/views/categroyManager/generalSettings/leaveManager"),
  cycleManager: () =>
    import("@/views/categroyManager/generalSettings/cycleManager"),
  overallManager: () =>
    import("@/views/categroyManager/generalSettings/overallManager"),
  payManager: () =>
    import("@/views/categroyManager/generalSettings/payManager"),
  insideSetting: () => import("@/views/categroyManager/insideSetting/index"),
  adminManager: () =>
    import("@/views/categroyManager/insideSetting/adminManager"),
  adminOperation: () =>
    import("@/views/categroyManager/insideSetting/adminOperation"),
  staffManager: () =>
    import("@/views/categroyManager/insideSetting/staffManager"),
  branchManager: () =>
    import("@/views/categroyManager/insideSetting/branchManager"),
  addressManager: () =>
    import("@/views/categroyManager/insideSetting/addressManager"),
  branchActive: () =>
    import("@/views/categroyManager/insideSetting/branchActive"),
  branchActiveOperation: () =>
    import("@/views/categroyManager/insideSetting/branchActiveOperation"),
  vipChargeSeting: () => import("@/views/categroyManager/vipChargeSeting"),
  vipActiveList: () => import("@/views/categroyManager/vipActiveList"),
  vipNewActive: () => import("@/views/categroyManager/vipNewActive"),
  vipParameterManager: () =>
    import("@/views/categroyManager/generalSettings/vipParameterManager"),
  globalConfig: () => import("@/views/categroyManager/globalConfig"),
  // 全局声部设置
  globalSubjects: () => import("@/views/categroyManager/globalSubjects"),
  // 全局乐团设置
  globalMusicGroup: () => import("@/views/categroyManager/globalMusicGroup"),
  // 全局产品设置
  productSystem: () => import("@/views/categroyManager/productSystem"),
  memberFeeSet: () =>
    import("@/views/categroyManager/productSystem/memberFeeSet"),
  memberSet: () => import("@/views/categroyManager/productSystem/memberSet"),
  // 侧边栏管理
  setSilder: () => import("@/views/setSilder/addSilder"),
  // 乐团老师点名记录
  teamTeacherRecord: () =>
    import("@/views/teamDetail/components/teamTeacherRecord"),
  // 乐团筹备中 报名中
  signupList: () => import("@/views/teamBuild/signupList"),
  remedy: () => import("@/views/teamBuild/signupList"),
  // 乐团筹备设置 (班级 老师 小课)
  teamSeting: () => import("@/views/teamBuild/teamSeting/"),
  //乐团详情
  teamDetails: () => import("@/views/teamDetail"),
  // 乐团课表详情
  teamDetailCourse: () => import("@/views/teamDetail/indexCourse"),
  // 学生点名总汇
  studentSignin: () => import("@/views/teamDetail/components/studentSignin"),
  // 班级调整
  resetClass: () => import("@/views/teamDetail/components/resetClass"),
  // 发放清单
  teamDetailedList: () => import("@/views/teamDetail/teamDetailedList"),
  // 基础技能班设置
  setImprovement: () =>
    import("@/views/teamBuild/teamSeting/components/setImprovement"),
  // 乐团修改 @/views/resetTeaming/index
  resetTeaming: () => import("@/views/resetTeaming/index"),
  // 乐团课排课
  coursePlan: () =>
    import("@/views/teamBuild/teamSeting/components/coursePlan"),
  // 收费分润管理
  chargeProfitManager: () =>
    import("../views/categroyManager/insideSetting/chargeProfitManager"),
  // 收费管理
  chargeManager: () => import("../views/chargeManager/index"),
  // 零星管理
  sporadicManager: () => import("@/views/sporadicManager/sporadicList"),
  // 课表列表
  teamCourseList: () => import("@/views/teamDetail/teamCourseList"),
  // 运营预警
  operationalList: () => import("@/views/operationalEarly/operationalList"),
  // 网管课列表
  accompanyList: () => import("@/views/accompanyManager/accompanyList"),
  // 网管课详情
  accompanys: () => import("@/views/accompanyManager/accompanys"),
  accompany: () => import("@/views/accompanyManager"),
  // 网管课购买
  accompanyBuys: () => import("@/views/accompanyManager/accompanyBuys"),
  // 版本控制
  editionList: () => import("@/views/editionManager/editionList"),
  // 定时任务
  timedTask: () => import("@/views/timedTask/index"),
  // 月报
  evaluateList: () => import("@/views/evaluateManager/evaluateList"),
  // 月报详情
  evaluateDetail: () => import("@/views/evaluateManager/evaluateDetail"),
  // 评价管理
  commentManager: () => import("@/views/evaluateManager"),
  // 网管课评价
  networkList: () => import("@/views/evaluateManager/networkList"),
  // 时间充值活动
  entryActivities: () => import("@/views/app/entryActivities"),
  // 添加或修改
  entryOperation: () => import("@/views/app/entryOperation"),
  // 意见反馈
  suggestion: () => import("@/views/app/suggestionIndex"),
  // 学练宝意见反馈
  clouldSuggestion: () => import("@/views/app/clouldSuggestion"),
  // 帮助分类
  helpCategory: () => import("@/views/helpCenter/helpCategory"),
  // 帮助内容
  helpContent: () => import("@/views/helpCenter/helpContent"),
  // 对外订单
  incomeOut: () => import("@/views/businessManager/orderManager/incomeOut"),
  // // 课外练习
  // afterSchoolList:()=>import('@/views/afterSchoolManager/afterSchoolList'),
  // // 课外练习
  // afterWorkList:()=>import('@/views/afterSchoolManager/afterWorkList'),
  // 课外管理
  afterSchoolManager: () => import("@/views/afterSchoolManager"),
  examination: () => import("@/views/afterSchoolManager/examination"),
  afterSchoolDetail: () =>
    import("@/views/afterSchoolManager/afterSchoolDetail"),
  // 运营管理 学员列表
  operateStudent: () => import("@/views/operateManager/operateStudent"),
  // 运营管理 结转奖励
  settlementList: () => import("@/views/settlementManager/settlementList"),
  // 运营管理 服务指标
  serverIndexList: () => import("@/views/operateManager/serverIndexList"),
  // 运营管理 服务指标详情
  serverIndexDetail: () => import("@/views/operateManager/serverIndexDetail"),
  // 维修单列表
  repairList: () => import("@/views/repairManager/repairList"),
  // 乐团缴费详情
  strudentPayInfo: () =>
    import("@/views/resetTeaming/components/strudentPayInfo"),
  // 学生缴费金额设置
  studentPayBase: () =>
    import("@/views/resetTeaming/components/studentPayBase"),
  // 考情列表
  recodeList: () => import("@/views/recodeManager/recodeList"),
  // 考级报名列表
  levelManager: () => import("@/views/levelManager/levelManager"),
  gradeManager: () => import("@/views/levelManager/gradeManager"),
  levelSetting: () => import("@/views/levelManager/levelSetting"),
  levelInformationSetting: () =>
    import("@/views/levelManager/levelInformationSetting"),
  // 汇会账号管理
  adapayManager: () => import("@/views/adapayAccount/index"),
  adapayOperation: () => import("@/views/adapayAccount/form"),
  // 日历课表
  calendarList: () =>
    import("@/views/teacherManager/teacherDetail/components/calendarList"),
  returnVisitList: () => import("@/views/returnVisitManager/index"),
  // 经营报表
  businessStatement: () =>
    import("@/views/businessManager/orderManager/businessStatement"),
  //经营详情
  businessStatementDetail: () =>
    import("@/views/businessManager/orderManager/businessStatementDetail"),
  // 支出记录
  payRecord: () => import("@/views/businessManager/orderManager/payRecord"),
  // 销售列表
  salesList: () => import("@/views/businessManager/orderManager/salesList"),
  // 人力资源
  HumanResources: () => import("@/views/HumanResources"),
  // 查看乐团基本信息
  teamLookBase: () => import("@/views/teamDetail/teamInfo"),
  // 更换列表
  resetList: () => import("@/views/businessManager/resetList"),
  // 进货清单
  purchaseLlist: () =>
    import("@/views/businessManager/shopManager/purchase-llist"),
  // 抽奖活动管理
  lotteryManager: () => import("@/views/luckyDraw/lotteryManager"),
  // 活动奖品设置
  trophyManager: () => import("@/views/luckyDraw/trophyManager"),
  // 抽奖记录
  lotteryRecord: () => import("@/views/luckyDraw/lotteryRecord"),
  // 审核列表
  auditList: () => import("@/views/auditList/index"),
  // 订单审核
  orderAudit: () => import("@/views/businessManager/orderManager/orderAudit"),
  orderAuditTaoqi: () =>
    import("@/views/businessManager/orderManager/orderAudit-taoqi"),
  // 长三角比赛
  matchManager: () => import("@/views/matchManager/index"),
  // 考勤列表
  attendanceList: () => import("@/views/attendanceManager/attendanceList"),
  // 学生考情列表
  stuRecodeManager: () => import("@/views/stuRecodeManager"),
  // 乐团班级列表
  teamCLassList: () => import("@/views/teamDetail/teamClassList"),
  // 乐团巡查
  musicInspection: () => import("@/views/musicInspection/index"),
  // 乐团主管日程详情
  scheduleDetail: () => import("@/views/main/teamSchedule/scheduleDetail"),
  // 乐团班级列表
  WithdrawalApplication: () => import("@/views/withdrawal-application"),
  // 欠费学员列表
  ArrearageStudents: () => import("@/views/arrearage-students"),
  // 课程组管理
  courseListManager: () => import("@/views/courseListManager"),
  // 班级管理
  classManager: () => import("@/views/courseListManager"),
  // 课程管理
  courseManager: () => import("@/views/courseListManager"),
  // 练习管理
  workManager: () => import("@/views/courseListManager"),
  // 老师管理
  teacherManager: () => import("@/views/courseListManager"),
  // 学生管理
  studentManager: () => import("@/views/courseListManager"),
  // 订单管理
  orderManager: () => import("@/views/courseListManager"),
  // 财务录入
  financeIn: () => import("@/views/courseListManager"),
  // vip参数设置
  vipSet: () => import("@/views/courseListManager"),
  // 基本信息配置
  sysBasics: () => import("@/views/courseListManager"),
  // 参数设置
  parameter: () => import("@/views/courseListManager"),
  // 抽奖活动
  luckyDraw: () => import("@/views/courseListManager"),
  // 乐团管理
  teamMananger: () => import("@/views/courseListManager"),
  // vip管理
  vipManager: () => import("@/views/courseListManager"),
  // 网管课管理
  accompanyManager: () => import("@/views/courseListManager"),
  // 乐团管理
  // 评论管理
  commentManagerWrap: () => import("@/views/courseListManager"),
  // 课外练习
  afterSchoolManagerWrap: () => import("@/views/courseListManager"),
  //
  serverIndexManager: () => import("@/views/courseListManager"),
  reportFormCenter: () => import("@/views/courseListManager"),
  // 乐器维护
  musicalManager: () => import("@/views/musicalManager"),
  // 服务指标明细
  branchActiveManager: () => import("@/views/courseListManager"),
  // vip活动管理
  vipActiveManager: () => import("@/views/courseListManager"),
  // 乐团缴费
  teamPayInfo: () => import("@/views/courseListManager"),
  serverDetail: () => import("@/views/serverDetail"),
  // 未在班级学员
  notClassStudent: () => import("@/views/main/notClassStudent"),
  // 报表中心 下载列表
  downList: () => import("@/views/reportForm/downList"),
  // 乐器置换
  reaplceMusicPlayer: () => import("@/views/reaplceMusicPlayer"),
  answerList: () => import("@/views/reaplceMusicPlayer/answerList"),
  // 问卷管理
  setQuestions: () => import("@/views/setQuestions"),
  questionOperation: () => import("@/views/setQuestions/operation"),
  // 21暑期考级
  childrensDay: () => import("@/views/childrensDay"),
  // 考级详情
  childrensdayDetail: () => import("@/views/childrensDay/detail"),
  // 异常数据
  indexErrDataRecord: () => import("@/views/indexErrDataRecord"),
  // 团练宝数据
  cloudDate: () => import("@/views/main/cloudDate/index.vue"),
  // 云课堂观看统计
  coursewareDate: () => import("@/views/main/coursewareDate/index.vue"),
  dictionaryManager: () => import("@/views/dictionaryManager"),
  // 会员排课列表
  memberClassList: () =>
    import("@/views/teamDetail/components/memberClassList"),
  // 设备号管理
  deviceNum: () => import("@/views/deviceNumManager"),
  // 乐团会员列表
  teamMemberList: () => import("@/views/studentManager/memberList"),
  //2021十一活动
  memeberActionManager: () => import("@/views/2021memeberActionManager"),
  // 优惠券管理
  couponManager: () => import("@/views/couponManager"),
  // 优惠券明细
  couponDetail: () => import("@/views/couponManager/couponDetail"),
  // 优惠券明细
  activeMarketing: () => import("@/views/activityScheduling/activeMarketing"),
  // 2021双11
  "2021double11List": () =>
    import("@/views/activityScheduling/2021double11List"),
  // 活动资格管理
  activeSenior: () => import("@/views/categroyManager/activeSenior"),
  backManager: () => import("@/views/backManager"),
  // 教材列表
  teachManager: () => import("@/views/teachManager"),
  // 教材分类
  teachClass: () => import("@/views/teachManager/teachClass"),
  // 课程规则设置
  courseRulersManager: () => import("@/views/courseRulersManager"),
  // 基础规则设置
  baseRulesManager: () => import("@/views/baseRulesManager"),
  // 课程参数设置
  baseRulesClassSetting: () => import("@/views/baseRulesClassSetting"),
  // 产品管理
  productManager: () => import("@/views/platformManager/productManger"),
  // 服务管理
  // 基本信息配置
  serviceManager: () => import("@/views/courseListManager"),
  serviceList: () => import("@/views/platformManager/serviceManager/index"),
  serviceOperation: () => import("@/views/platformManager/serviceManager/form"),
  // 机构申请
  tenantApply: () => import("@/views/platformManager/tenantApply"),
  // 学练宝流量包
  cloudTrafficPackage: () =>
    import("@/views/platformManager/cloudTrafficPackage"),
  accompanyBaseConfig: () =>
    import("@/views/categroyManager/accompanyBaseConfig"),
  // 网管课价格配置
  accompanyFeeConfig: () =>
    import("@/views/categroyManager/accompanyFeeConfig"), // 机构列表
  organList: () => import("@/views/organManager"),
  organOperation: () => import("@/views/organManager/organOperation"),
  // 课酬预警
  earlyWarning: () =>
    import("@/views/categroyManager/generalSettings/earlyWarning"),
  holidaySetting: () =>
    import("@/views/categroyManager/generalSettings/holidaySetting"),
  // 平台课程默认值
  platformCourseDeault: () =>
    import("@/views/platformManager/platformCourseDeault"),
  // 特殊参数默认值
  specialDeault: () => import("@/views/baseRulesManager/special.vue"),
  // 机构设置
  tenantInfoSetting: () => import("@/views/tenantSetting/tenantInfo.vue"),
  // 机构协议管理
  tenantInfoProtocol: () =>
    import("@/views/tenantSetting/tenantInfoProtocol.vue"),
  // 机构交易管理
  tenantTradeManager: () =>
    import("@/views/tenantSetting/tenantTradeManager.vue"),
  // 学练宝激活记录
  groupRecordManager: () =>
    import("@/views/tenantSetting/groupRecordManager.vue"),
  // 扣费记录
  chargingRecord: () => import("@/views/tenantSetting/chargingRecord.vue"),
  // 操作手册管理
  operationManual: () => import("@/views/operationManual"),
  // 产品服务
  productService: () => import("@/views/productService"),
  // 声部分类列表
  subjectCategroyList: () =>
    import("@/views/categroyManager/subjectCategroyList"),
  // oa信息管理
  OAMananger: () => import("@/views/OAMananger"),
  // 平台员工管理
  staffPlatManager: () =>
    import("@/views/categroyManager/insideSetting/staffPlatManager"),
  //邮件配置服务
  mailInfoManager: () => import("@/views/mailInfoManager"),
  // 机构协议管理
  protocolManagement: () => import("@/views/protocolManagement"),
  //
  studentGroupPractice: () =>
    import("@/views/studentManager/studentGroupPractice"),
  // 学练宝缴费记录
  studentGroupRecord: () => import("@/views/studentManager/studentGroupRecord"),
  // 直播课管理
  liveClassManager: () => import("@/views/liveClassManager"),
  // 新建直播课
  createLiveClass: () => import("@/views/liveClassManager/newLiveClass"),
  createLiveCourse: () => import("@/views/liveClassManager/createLiveClass"),
  // 直播课详情
  liveClassDetail: () => import("@/views/liveClassManager/liveClassDetail"),
  liveClassTwo: () => import("@/views/liveClassManager/liveClassTwo"),
  // 平台员工管理
  platformAdminManger: () => import("@/views/platformManager/paltformAdmin"),
  // 小课学员管理
  smallStudentManager: () => import("@/views/smallStudentManager"),
  // 代理商管理
  agentList: () => import("@/views/agentManager/agentList"),
  // 学练宝分润
  memberShareList: () => import("@/views/agentManager/memberShareList"),
  // 群组管理
  groupChatManager: () => import("@/views/groupChatManager"),
  // 群聊公告
  sysGroupCat: () => import("@/views/groupChatManager/sysGroupCat"),
  // 小小艺术家练习营
  littleArtistCamp: () => import("@/views/littleArtistCamp"),
  liveShopManger: () => import("@/views/liveShopManger"),
  // 学员乐保
  studentLebaoManager: () => import("@/views/studentLebaoManager"),
  // 排课资格
  courseCredentials: () => import("@/views/courseCredentials"),
  // 合作单位缴费
  branchPayManager: () => import("@/views/branchPayManager/payList"),
  // 合作单位分润 payShareList
  branchShareManager: () => import("@/views/branchPayManager/payShareList"),
  smallCourseConsumption: () =>
    import("@/views/smallCourseConsumption/index.vue"),
  // 练习详情
  exerciseDurationDetail: () =>
    import("@/views/main/cloudDate/exerciseDurationDetail.vue"),
  // 练习详情
  coursewareDurationDetail: () =>
    import("@/views/main/coursewareDate/exerciseDurationDetail.vue"),
  // 新课表列表
  newCourseList: () => import("@/views/newCourseList"),
  newOrderList: () => import("@/views/newCourseList/orderList"),
  schoolPatrol: () => import("@/views/schoolManager/patrol.vue"),
  accountManager: () => import("@/views/schoolManager/accountManager.vue"),
  // 课件配置
  coursewareConfig: () => import("@/views/courseware-config/index.vue"),
  // 乐队指导特训营
  bandGuidanceTraining: () => import("@/views/band-guidance-training"),
  // 乐队指导特训营详情
  bandGuidanceTrainingDetail: () => import("@/views/band-guidance-training/detail"),
};
export default router;
